@@ -1,25 +1,32 @@
-import json
-import re
+"""Asynchronous Python client for Russound RIO."""
+
+from __future__ import annotations
+
 from collections import defaultdict
 from enum import Enum
+import re
 
-MAX_ZONES_KEY = "max_zones"
-RNET_SUPPORT_KEY = "rnet_support"
-
-MINIMUM_API_SUPPORT = "1.02.00"
+MINIMUM_API_SUPPORT = "1.05.00"
 
 DEFAULT_PORT = 9621
 
 RECONNECT_DELAY = 5.0
 TIMEOUT = 5.0
 
+KEEP_ALIVE_INTERVAL = 60
+
+MAX_SOURCE = 17
+
+MAX_RNET_CONTROLLERS = 6
+
 RESPONSE_REGEX = re.compile(
-    r"^(?:C\[(?P<controller>\d+)](?:\.Z\[(?P<zone>\d+)])?|S\[(?P<source>\d+)])?\.(?P<variable>\S+)=\s*\"("
-    r"?P<value>.*)\"$|^(?P<variable_only>\S+)=\s*\"(?P<value_only>.*)\"$"
+    r'(?:(\w+(?:\[\d+])?(?:\.\w+(?:\[\d+])?)*)\.)?(\w+)="([^"]*)"'
 )
 
 
 class FeatureFlag(Enum):
+    """A list of Russound RIO API features."""
+
     SUPPORT_POWER_MGMT = 1
     SUPPORT_ZONE_PARAMETERS = 2
     SUPPORT_SOURCE_PARAMETERS = 3
@@ -82,7 +89,7 @@ FLAGS_BY_VERSION = {
     "1.03.00": [
         FeatureFlag.SUPPORT_DMS_3_1_MM,
         FeatureFlag.EVENT_KEY_CODE,
-        FeatureFlag.PROPERTY_IP_ADDRESS
+        FeatureFlag.PROPERTY_IP_ADDRESS,
     ],
     "1.04.00": [
         FeatureFlag.SUPPORT_SHUFFLE,
@@ -108,9 +115,7 @@ FLAGS_BY_VERSION = {
         FeatureFlag.SUPPORT_MEDIA_RATING,
         FeatureFlag.SUPPORT_HIDDEN_ATTRIBUTE,
     ],
-    "1.08.00": [
-        FeatureFlag.SUPPORT_SYSTEM_FAVORITE_RENAME
-    ],
+    "1.08.00": [FeatureFlag.SUPPORT_SYSTEM_FAVORITE_RENAME],
     "1.09.00": [
         FeatureFlag.COMMANDS_ZONE_MUTE_OFF_ON,
     ],
@@ -138,16 +143,13 @@ FLAGS_BY_VERSION = {
         FeatureFlag.PROPERTY_PLAY_TIME,
         FeatureFlag.PROPERTY_TRACK_TIME,
         FeatureFlag.PROPERTY_SET_SEEK_TIME,
-        FeatureFlag.SUPPORT_MM_CONTEXT_MENU
+        FeatureFlag.SUPPORT_MM_CONTEXT_MENU,
     ],
     "1.14.01": [
         FeatureFlag.PROPERTY_SLEEP_TIME_DEFAULT,
         FeatureFlag.PROPERTY_SUPPORT_SLEEP_TIME,
     ],
-    "1.15.00": [
-        FeatureFlag.EVENT_REBOOT,
-        FeatureFlag.SUPPORT_SYSTEM_FAVORITE_SOURCE
-    ],
+    "1.15.00": [FeatureFlag.EVENT_REBOOT, FeatureFlag.SUPPORT_SYSTEM_FAVORITE_SOURCE],
     "1.15.02": [
         FeatureFlag.ATTRIBUTE_USER_LOGIN,
     ],
@@ -155,13 +157,11 @@ FLAGS_BY_VERSION = {
 
 VERSIONS_BY_FLAGS = defaultdict(list)
 
-ZONE_PROPERTIES = [
-    'currentSource'
-]
-
-SOURCE_PROPERTIES = [
-]
-
 for version, flags in FLAGS_BY_VERSION.items():
     for flag in flags:
         VERSIONS_BY_FLAGS[flag] = version
+
+CONTROLLER_TYPE_FIX_MAP = {
+    "MCA-C6": "MCA-C5",
+    "XStream-X5": "XSource",
+}
\ No newline at end of file
